From: Wakou Aoyama Date: 1999-07-27T14:25:38+09:00 Subject: [ruby-dev:7440] Re: jcode.rb 青山です。 On Tue, Jul 27, 1999 at 01:15:44PM +0900, WATANABE Hirofumi wrote: > $_.gsub!(/[ァ-ン]/){|c| Kana2Hira[c] } > にしないと多分なにも置換されないから不公平なテストです :-) あ、お恥ずかしい。 $ time ruby -rjcode -pe ' BEGIN { Kana2Hira = {} a = "ぁ" ("ァ" .. "ン").each{|c| Kana2Hira[c] = a.dup; a.succ! } } $_.gsub!(/[ァ-ン]/){|c| Kana2Hira[c] } ' test.txt > /dev/null real 0m0.657s user 0m0.600s sys 0m0.060s しかし、それでもやはり速いですね。 > 現在はさらなる高速化を計ってます. > あと 2 倍ぐらいは速くなりそう. それは凄いですね。test.txt は 400kb ぐらいありますから、これが2秒以下 となると、オリジナルには追い付かなくても実用には十分ですね。 -- 青山 和光 Wakou Aoyama